<?php
/**
 * A command for the money refill page
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebMoneyRefillFormCommand extends BaseCommand implements Commandable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removeSystemArray();
	}

	/**
	 * Creates an instance of this command and sets the resolver instance
	 *
	 * @param	$resolverInstance	An instance of a command resolver
	 * @return	$commandInstance	The created command instance
	 */
	public final static function createWebMoneyRefillFormCommand (CommandResolver $resolverInstance) {
		// Get a new instance
		$commandInstance = new WebMoneyRefillFormCommand();

		// Set the resolver instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	0% done
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		$this->partialStub("Please implement this method.");
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
		// Add user auth filter (we don't need an update of the user here because it will be redirected)
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_auth_class'));

		// Add user status filter here
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_status_class'));

		// Is the refill page active?
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('refill_page_class'));

		// Verify CAPTCHA code
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('captcha_refill_verifier_class'));

		// Verify refill request
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('refill_request_validator_class'));
	}
}

// [EOF]
?>
