<?php
/**
 * The application selector main include file
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// Get config instance
$cfg = FrameworkConfiguration::getInstance();

// Try to load these includes in the given order
$configAppIncludes = array(
	sprintf("class_%s", $cfg->readConfig('app_helper_class')), // The ApplicationHelper class
	"config",		// The application's own configuration
	"init",			// The application initializer
	"loader",		// The application's class loader
	"debug",		// Some debugging stuff
	"exceptions",	// The application's own exception handler
	"starter",		// The application starter (calls entryPoint(), etc.)
);

// Load them all (try only)
foreach ($configAppIncludes as $inc) {
	// Skip starter in test mode
	if (($inc == "starter") && (defined('TEST'))) {
		// Skip it here
		continue;
	}

	// Generate a FQFN for the helper class
	$fqfn = sprintf("%s%s/%s/%s%s",
		$cfg->readConfig('base_path'),
		$cfg->readConfig('application_path'),
		$cfg->readConfig('app_name'),
		$inc,
		$cfg->readConfig('php_extension')
	);

	// Does the include file exists?
	if ((file_exists($fqfn)) && (is_file($fqfn)) && (is_readable($fqfn))) {
		// Load it
		require_once($fqfn);
	} elseif ($cfg->readConfig('verbose_level') > 0) {
		// File is missing
		trigger_error(sprintf("Cannot load application script %s! File is missing or read-protected.",
			$inc . $cfg->readConfig('php_extension')
		));
	}
}

// [EOF]
?>
